Modules
Macros
- derive_
iterable - Derive
Quinefor an iterable T where: - derive_
primitive - derive_
trivial - Derive the
Quinetrait for an arbitrary type that implementsquote::ToTokens. The generated constructor is an expression in the formT::from(#self). - derive_
tuple - Derive the
Quinetrait for a tuple (T1, …, Tn). This is already done for some tuple sizes - use this macro if you encounter an unsupported tuple. - derive_
tuple_ all